@@ -23,6 +23,15 @@ class DraftRecordIdProviderV2(RecordIdProviderV2):
     default_status_with_obj = PIDStatus.NEW
 
 
+class ParentRecord(RecordBase):
+    """Parent record API."""
+
+    # Configuration
+    model_cls = None
+
+    pid = PIDField('id', provider=DraftRecordIdProviderV2, delete=True)
+
+
 class Record(RecordBase):
     """Record base API.
 
@@ -32,39 +41,52 @@ class Record(RecordBase):
     # Configuration
     model_cls = None
 
-    pid = PIDField('id', provider=DraftRecordIdProviderV2)
-
-    conceptpid = PIDField('conceptid', provider=DraftRecordIdProviderV2)
+    pid = PIDField('id', provider=DraftRecordIdProviderV2, delete=True)
 
     is_published = PIDStatusCheckField(status=PIDStatus.REGISTERED)
 
+    #: List of field names (strings) to copy from the draft on create.
+    create_from_draft = []
+
+    #: List of field names (strings) to copy from the draft on update.
+    update_from_draft = []
+
+    # TODO: Below three methods create_from(), update_from() and register() has
+    # to be refactored. They are accessing "parent" but it may not be defined.
+    # Instead, this work should be delegated to the system fields, but it's not
+    # easy to add a new pre/post_create_from pre/post_register hook.
     @classmethod
-    def create_or_update_from(cls, draft):
-        """Create of update the record based on the draft content."""
-        try:
-            # New version
-            record = cls.get_record(draft.id)
-        except NoResultFound:
-            # New revision
-            record = cls.create(
-                {}, id_=draft.id, pid=draft.pid, conceptpid=draft.conceptpid)
+    def create_from(cls, draft):
+        """Create a new record from a draft."""
+        record = cls.create(
+            {},
+            id_=draft.id,
+            pid=draft.pid,
+            **{f: getattr(draft, f) for f in cls.create_from_draft}
+        )
 
-        # NOTE: Merge pid/conceptpid into the current db session if not already
-        # in the session.
+        # NOTE: Merge pid into the current db session if not already in the
+        # session.
         cls.pid.session_merge(record)
-        cls.conceptpid.session_merge(record)
+        record.parent.__class__.pid.session_merge(record.parent)
 
-        # Overwrite data
-        # FIXME: Data validation should be done one step up self.schema access
-        # TODO: Does this overwrite the pids/conceptpids?
-        record.update(**draft)
+        record.update_from(draft)
 
         return record
 
+    def update_from(self, draft):
+        """Update a record from a draft."""
+        # Overwrite data
+        self.update(**draft)
+        for f in self.update_from_draft:
+            setattr(self, f, getattr(draft, f))
+        return self
+
     def register(self):
-        """Register the persistent identifiers associated with teh record."""
-        if not self.conceptpid.is_registered():
-            self.conceptpid.register()
+        """Register the persistent identifiers associated with the record."""
+        if not self.parent.pid.is_registered():
+            self.parent.pid.register()
+            self.parent.commit()
         self.pid.register()
 
 
@@ -77,9 +99,6 @@ class Draft(Record):
 
     pid = PIDField('id', provider=DraftRecordIdProviderV2, delete=False)
 
-    conceptpid = PIDField(
-        'conceptid', provider=DraftRecordIdProviderV2,  delete=False)
-
     expires_at = ModelField()
 
     fork_version_id = ModelField()
