@@ -4,9 +4,23 @@ from invenio_records.systemfields import ConstantField
 from invenio_records_resources.records.systemfields import IndexField
 
 from invenio_drafts_resources.records.api import Draft as DraftBase
+from invenio_drafts_resources.records.api import \
+    ParentRecord as ParentRecordBase
 from invenio_drafts_resources.records.api import Record as RecordBase
+from invenio_drafts_resources.records.systemfields import ParentField
 
-from .models import DraftMetadata, RecordMetadata
+from .models import DraftMetadata, ParentRecordMetadata, RecordMetadata
+
+
+class ParentRecord(ParentRecordBase):
+    """Example parent record."""
+
+    # Configuration
+    model_cls = ParentRecordMetadata
+
+    # System fields
+    schema = ConstantField(
+        '$schema', 'http://localhost/schemas/records/parent-v1.0.0.json')
 
 
 class Record(RecordBase):
@@ -24,6 +38,13 @@ class Record(RecordBase):
         search_alias='draftsresources-records'
     )
 
+    parent = ParentField(
+        ParentRecord, create=False, soft_delete=False, hard_delete=False)
+
+    create_from_draft = [
+        'parent'
+    ]
+
 
 class Draft(DraftBase):
     """Example record API."""
@@ -39,3 +60,6 @@ class Draft(DraftBase):
         'draftsresources-drafts-draft-v1.0.0',
         search_alias='draftsresources-drafts'
     )
+
+    parent = ParentField(
+        ParentRecord, create=True, soft_delete=False, hard_delete=True)
